searchData={"items":[{"type":"module","title":"TableRex","doc":"TableRex generates configurable, text-based tables for display","ref":"TableRex.html"},{"type":"function","title":"TableRex.quick_render/3","doc":"A shortcut function to render with a one-liner.\nSacrifices all customisation for those that just want sane defaults.\nReturns `{:ok, rendered_string}` on success and `{:error, reason}` on failure.","ref":"TableRex.html#quick_render/3"},{"type":"function","title":"TableRex.quick_render!/3","doc":"A shortcut function to render with a one-liner.\nSacrifices all customisation for those that just want sane defaults.\nReturns the `rendered_string` on success and raises `RuntimeError` on failure.","ref":"TableRex.html#quick_render!/3"},{"type":"module","title":"TableRex.Cell","doc":"Defines a struct that represents a single table cell, and helper functions.\n\nA cell stores both the original data _and_ the string-rendered version,\nthis decision was taken as a tradeoff: this way uses more memory to store\nthe table structure but the renderers gain the ability to get direct access\nto the string-coerced data rather than having to risk repeated coercion or\nhandle their own storage of the computer values.\n\nFields:\n\n  * `raw_value`: The un-coerced original value\n\n  * `rendered_value`: The stringified value for rendering\n\n  * `wrapped_lines`: A list of 1 or more string values representing\n    the line(s) within the cell to be rendered\n\n  * `align`:\n    * `:left`: left align text in the cell.\n    * `:center`: center text in the cell.\n    * `:right`: right align text in the cell.\n    * `nil`: align text in cell according to column alignment.\n\n  * `color`: the ANSI color of the cell.\n\nIf creating a Cell manually: raw_value is the only required key to\nenable that Cell to work well with the rest of TableRex. It should\nbe set to a piece of data that can be rendered to string.","ref":"TableRex.Cell.html"},{"type":"function","title":"TableRex.Cell.height/1","doc":"","ref":"TableRex.Cell.html#height/1"},{"type":"function","title":"TableRex.Cell.to_cell/1","doc":"Converts the passed value to be a normalised %Cell{} struct.\n\nIf a non %Cell{} value is passed, this function returns a new\n%Cell{} struct with:\n\n  * the `rendered_value` key set to the stringified binary of the\n    value passed in.\n  * the `raw_value` key set to original data passed in.\n  * any other options passed are applied over the normal struct\n    defaults, which allows overriding alignment & color.\n\nIf a %Cell{} is passed in with no `rendered_value` key, then the\n`raw_value` key's value is rendered and saved against it, otherwise\nthe Cell is passed through untouched. This is so that advanced use\ncases which require direct Cell creation and manipulation are not\nhindered.","ref":"TableRex.Cell.html#to_cell/1"},{"type":"function","title":"TableRex.Cell.to_cell/2","doc":"","ref":"TableRex.Cell.html#to_cell/2"},{"type":"type","title":"TableRex.Cell.t/0","doc":"","ref":"TableRex.Cell.html#t:t/0"},{"type":"module","title":"TableRex.Column","doc":"Defines a struct that represents a column's metadata\n\nThe align field can be one of :left, :center or :right.","ref":"TableRex.Column.html"},{"type":"type","title":"TableRex.Column.t/0","doc":"","ref":"TableRex.Column.html#t:t/0"},{"type":"behaviour","title":"TableRex.Renderer","doc":"An Elixir behaviour that defines the API Renderers should conform to, allowing\nfor display output in a variety of formats.","ref":"TableRex.Renderer.html"},{"type":"callback","title":"TableRex.Renderer.default_options/0","doc":"Returns a Map of the options and their default values required by the renderer.","ref":"TableRex.Renderer.html#c:default_options/0"},{"type":"callback","title":"TableRex.Renderer.render/2","doc":"Renders a passed %TableRex.Table{} struct into a string.","ref":"TableRex.Renderer.html#c:render/2"},{"type":"type","title":"TableRex.Renderer.render_return/0","doc":"Return value of the render function.","ref":"TableRex.Renderer.html#t:render_return/0"},{"type":"module","title":"TableRex.Renderer.Text","doc":"Renderer module which handles outputting ASCII-style tables for display.","ref":"TableRex.Renderer.Text.html"},{"type":"function","title":"TableRex.Renderer.Text.default_options/0","doc":"Provides a level of sane defaults for the Text rendering module.","ref":"TableRex.Renderer.Text.html#default_options/0"},{"type":"function","title":"TableRex.Renderer.Text.render/2","doc":"Implementation of the TableRex.Renderer behaviour.\n\nAvailable styling options.\n\n`horizontal_styles` controls horizontal separators and can be one of:\n\n  * `:all`: display separators between and around every row.\n  * `:header`: display outer and header horizontal separators only.\n  * `:frame`: display outer horizontal separators only.\n  * `:gfm`: display all separators except top and bottom to comply with github flavored markdown \n  * `:off`: display no horizontal separators.\n\n`vertical_styles` controls vertical separators and can be one of:\n\n  * `:all`: display between and around every column.\n  * `:frame`: display outer vertical separators only.\n  * `:off`: display no vertical separators.","ref":"TableRex.Renderer.Text.html#render/2"},{"type":"module","title":"TableRex.Renderer.Text.Meta","doc":"The data structure for the `TableRex.Renderer.Text` rendering module, it holds results\nof style & dimension calculations to be passed down the render pipeline.","ref":"TableRex.Renderer.Text.Meta.html"},{"type":"function","title":"TableRex.Renderer.Text.Meta.col_width/2","doc":"Retrieves the column width at the given column index.","ref":"TableRex.Renderer.Text.Meta.html#col_width/2"},{"type":"function","title":"TableRex.Renderer.Text.Meta.inner_width/1","doc":"Retrieves the \"inner width\" of the table, which is the full width minus any frame.","ref":"TableRex.Renderer.Text.Meta.html#inner_width/1"},{"type":"function","title":"TableRex.Renderer.Text.Meta.row_height/2","doc":"Retrieves the row width at the given row index.","ref":"TableRex.Renderer.Text.Meta.html#row_height/2"},{"type":"module","title":"TableRex.Table","doc":"A set of functions for working with tables.\n\nThe `Table` is represented internally as a struct though the\nfields are private and must not be accessed directly. Instead,\nuse the functions in this module.","ref":"TableRex.Table.html"},{"type":"function","title":"TableRex.Table.add_row/2","doc":"Adds a single row to the table.","ref":"TableRex.Table.html#add_row/2"},{"type":"function","title":"TableRex.Table.add_rows/2","doc":"Adds multiple rows to the table.","ref":"TableRex.Table.html#add_rows/2"},{"type":"function","title":"TableRex.Table.clear_all_column_meta/1","doc":"Removes column meta for all columns, effectively resetting\ncolumn meta back to the default options across the board.","ref":"TableRex.Table.html#clear_all_column_meta/1"},{"type":"function","title":"TableRex.Table.clear_rows/1","doc":"Removes all row data from the table, keeping everything else.","ref":"TableRex.Table.html#clear_rows/1"},{"type":"function","title":"TableRex.Table.get_column_meta/3","doc":"Retrieves the value of a column meta option at the specified col_index.\nIf no value has been set, default values are returned.","ref":"TableRex.Table.html#get_column_meta/3"},{"type":"function","title":"TableRex.Table.has_header?/1","doc":"Returns a boolean detailing if the passed table has a header row set.","ref":"TableRex.Table.html#has_header?/1"},{"type":"function","title":"TableRex.Table.new/0","doc":"Creates a new blank table.\n\nThe table created will not be able to be rendered until it has some row data.","ref":"TableRex.Table.html#new/0"},{"type":"function","title":"Examples - TableRex.Table.new/0","doc":"iex> Table.new\n    %TableRex.Table{}","ref":"TableRex.Table.html#new/0-examples"},{"type":"function","title":"TableRex.Table.new/3","doc":"Creates a new table with an initial set of rows and an optional header and title.","ref":"TableRex.Table.html#new/3"},{"type":"function","title":"TableRex.Table.put_cell_meta/4","doc":"Sets cell level information such as alignment.","ref":"TableRex.Table.html#put_cell_meta/4"},{"type":"function","title":"TableRex.Table.put_column_meta/3","doc":"Sets column level information such as padding and alignment.","ref":"TableRex.Table.html#put_column_meta/3"},{"type":"function","title":"TableRex.Table.put_header/2","doc":"Sets a list as the optional header row.\nSet to `nil` or `[]` to remove an already set header from renders.","ref":"TableRex.Table.html#put_header/2"},{"type":"function","title":"TableRex.Table.put_header_meta/3","doc":"Sets cell level information for the header cells.","ref":"TableRex.Table.html#put_header_meta/3"},{"type":"function","title":"TableRex.Table.put_title/2","doc":"Sets a string as the optional table title.\nSet to `nil` or `\"\"` to remove an already set title from renders.","ref":"TableRex.Table.html#put_title/2"},{"type":"function","title":"TableRex.Table.render/2","doc":"Renders the current table state to string, ready for display via `IO.puts/2` or other means.\n\nAt least one row must have been added before rendering.\n\nReturns `{:ok, rendered_string}` on success and `{:error, reason}` on failure.","ref":"TableRex.Table.html#render/2"},{"type":"function","title":"TableRex.Table.render!/2","doc":"Renders the current table state to string, ready for display via `IO.puts/2` or other means.\n\nAt least one row must have been added before rendering.\n\nReturns the rendered string on success, or raises `TableRex.Error` on failure.","ref":"TableRex.Table.html#render!/2"},{"type":"function","title":"TableRex.Table.row_colors/2","doc":"","ref":"TableRex.Table.html#row_colors/2"},{"type":"function","title":"TableRex.Table.sort/3","doc":"Sorts the table rows by using the values in a specified column.\n\nThis is very much a simple sorting function and relies on Elixir's\nbuilt-in comparison operators & types to cover the basic cases.\n\nAs each cell retains the original value it was created with, we\nuse that value to sort on as this allows us to sort on many\nbuilt-in types in the most obvious fashions.\n\nRemember that rows are stored internally in reverse order that\nthey will be output in, to allow for fast insertion.\n\nParameters:\n\n    `column_index`: the 0-indexed column number to sort by\n    `order`: supply :desc or :asc for sort direction.\n\nReturns a new Table, with sorted rows.","ref":"TableRex.Table.html#sort/3"},{"type":"type","title":"TableRex.Table.t/0","doc":"","ref":"TableRex.Table.html#t:t/0"},{"type":"exception","title":"TableRex.Error","doc":"","ref":"TableRex.Error.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v4.1.0 (2025-02-16) - Changelog","doc":"Feature:\n\n* Adds GitHub Flavoured Markdown support to the `horizontal_style` parameter.\n  This allows TableRex to output tables while skipping the very top and bottom\n  of the frames, which happens to be exactly how GitHub Flavoured Markdown\n  renders tables.\n\nBugfix:\n\n* Fixes Elixir 1.17 warnings about function call without parens.\n* Fixes Elixir 1.19 warnings about map update ops.","ref":"changelog.html#v4-1-0-2025-02-16"},{"type":"extras","title":"v4.0.0 (2023-06-28) - Changelog","doc":"Dropped official support for Elixir 1.7->1.12. Only 1.13 & up.\n\nNo other changes.","ref":"changelog.html#v4-0-0-2023-06-28"},{"type":"extras","title":"v3.2.0 (2023-06-28) - Changelog","doc":"New features:\n\n* CJK/Unicode character support at the cell level. Non-ascii characters\n  should no longer break rendering.\n\n* We now have row-level support for colored backgrounds and foregrounds,\n  see some [examples](https://github.com/djm/table_rex/pull/44).\n\n* Tables can now have no rows if they wish; that constraint has been relaxed\n  & tables will render fine without any rows (e.g if they just have a header).","ref":"changelog.html#v3-2-0-2023-06-28"},{"type":"extras","title":"v3.1.1 (2021-01-30) - Changelog","doc":"Bugfix: Fixes a multiline text rendering crash when inputs had differing\nlengths. Thanks to @chulkilee for the fix.\n\nNo breaking changes.","ref":"changelog.html#v3-1-1-2021-01-30"},{"type":"extras","title":"v3.1.0 (2020-12-31) - Changelog","doc":"Multiline cell support 🎉\n\nThanks to @rubysolo, TableRex's ASCII-style plain text renderer has gained the\nability to render multiline strings without any extra effort on behalf of the\ncalling clients, simply insert your line breaks into your strings and the\nfeature will handle rendering with correct padding, coloring & alignment.\n\nNo (known) breaking changes.","ref":"changelog.html#v3-1-0-2020-12-31"},{"type":"extras","title":"v3.0.0 (2020-04-19) - Changelog","doc":"**No external API changes**, but we are dropping support for Elixir v1.7 and below\nalong with Erlang OTP v20 and below and as such the major version number is\nbumping to appreciate that.","ref":"changelog.html#v3-0-0-2020-04-19"},{"type":"extras","title":"v2.0.0 (2018-04-30) - Changelog","doc":"Version 2 has no external API breaking changes but we are bumping the major version\nnumber as the internal data structure of the %Cell{} struct has changed. See\nnote below.\n\nNew features:\n\n* sort! Tables can now have a basic sort function which uses Elixir's term\n  ordering to sort your table rows by a specific column in either ascending or\n  descending order. Please see the README for usage; many thanks to everyone\n  at @elixir-poa for this change.\n\n* you are now free to add your own ANSI color wrappers to text within an inline\n  cell, the extra characters this adds are ignored as part of width calculations\n  and therefore the structure of the table no longer breaks when you do this.\n  Thanks to @geolessel for this change.\n\n\n**%Cell{} struct change**\n\nPreviously Cells only stored the string-coerced version of the data you wanted\nto insert into the table. This was limiting as it meant we could not sort your\ntables as type information was lost in that process. It also opens up TableRex\nto many other features now that we keep the original data.\n\nThe stringified value of a Cell used to be stored at `value`, it is now stored\nat `rendered_value` - with the original being stored at `raw_value`.\n\nTo migrate:\n\n* If you are creating Cells, instead of passing `value`, pass `raw_value`.\n* If you are using Cells, it's likely you'll want to use `Cell.rendered_value`\n  which is now what the removed `Cell.value` used to be.","ref":"changelog.html#v2-0-0-2018-04-30"},{"type":"extras","title":"v1.0.0 (2017-12-11) - Changelog","doc":"The API seems stable enough, sans major complaints, and has no major open bugs\nso here is our version 1 release!\n\nThis release brings only new feature:\n\n* TableRex has gained the ability to stretch the table width to accommodate long\ntitles, thanks to @matt-harvey.\n\nAnd one breaking change:\n\n* We are dropping support for Elixir v1.2.x and Erlang 18.x. For the time\nbeing, we support the latest 3 minor versions of Elixir, and the latest 2\nmajor versions for Erlang.\n\nFrom now on - as per semver, new breaking changes will increment the major release\nnumber, new non-breaking features will increment the minor release number and\nbug fixes will update the patch number.","ref":"changelog.html#v1-0-0-2017-12-11"},{"type":"extras","title":"v0.10.0 (2017-01-14) - Changelog","doc":"**Breaking changes**\n\nDropped support for Elixir v1.1.x. We support the latest 3 minor versions, and\nthe latest 2 major versions for Erlang OTP.\n\nOther changes:\n\nFixed all compiler warnings resulting from Elixir 1.3 and 1.4 releases.","ref":"changelog.html#v0-10-0-2017-01-14"},{"type":"extras","title":"v0.9.0 (2017-01-14) - Changelog","doc":"Justin G (@theredcoder) has added support for header, column and cell level\nforeground & background ANSI colouring. Many thanks to Justin.","ref":"changelog.html#v0-9-0-2017-01-14"},{"type":"extras","title":"v0.8.3 (2016-08-12) - Changelog","doc":"Fixed warnings caused by Elixir 1.3's unsafe variable checker.","ref":"changelog.html#v0-8-3-2016-08-12"},{"type":"extras","title":"v0.8.2 (2016-08-12) - Changelog","doc":"Updated some locked development dependencies to reduce warning output during usage.","ref":"changelog.html#v0-8-2-2016-08-12"},{"type":"extras","title":"v0.8.1 (2016-06-30) - Changelog","doc":"Fixed a compilation bug in the new Elixir 1.3. No other changes.","ref":"changelog.html#v0-8-1-2016-06-30"},{"type":"extras","title":"v0.8.0 (2016-01-19) - Changelog","doc":"**Breaking changes**\n\nAll `Table.set_*` functions have been changed to `Table.put_*` to better\nreflect their functionality and mimic convention used elsewhere in the\nElixir ecosphere.","ref":"changelog.html#v0-8-0-2016-01-19"},{"type":"extras","title":"v0.7.0 (2016-01-09) - Changelog","doc":"**Breaking changes**\n\nThe default alignment for columns is now `:left` rather than `:center`.\n\nThis could be a breaking change for your project as if you had not explicitly\nset columns to be of a certain alignment then your tables will now be output\nwith columns aligned to the left rather than centered as before. This change\nwas made as it's much more likely that a LTR language user is going to want\nleft aligned columns, especially with the multiline cell support which will\nland soon.\n\nIf you wish to remain using center-aligned columns then you can manipulate\nyour table struct by calling:\n\n```elixir\nTable.set_column_meta(table, :all, align: :center)\n```\n\nOther changes:\n\n`Table.set_column_meta` and `Table.set_header_meta` now can also take their\ncolumn index(es) argument as an enumerable. Previously `set_header_meta` could\nnot do this and `set_column_meta` could only be provided a range.\n\nExample usage:\n\n```elixir\nTable.set_column_meta(table, 0, align: :right) # aligns column 0 to the right.\nTable.set_column_meta(table, 0..4, align: :right) # aligns column 0 through 4 to the right.\nTable.set_column_meta(table, [0, 3, 5], align: :right) # aligns column 0, 3 & 5 to the right.\nTable.set_column_meta(table, :all, align: :right) # aligns all current and future columns to the right.\n```\n\n```elixir\nTable.set_header_meta(table, 0, align: :right) # aligns header cell 0 to the right.\nTable.set_header_meta(table, 0..4, align: :right) # aligns header cells 0 through 4 to the right.\nTable.set_header_meta(table, [0, 3, 5], align: :right) # aligns header cells 0, 3 & 5 to the right.\n```","ref":"changelog.html#v0-7-0-2016-01-09"},{"type":"extras","title":"v0.6.0 (2016-01-07) - Changelog","doc":"**No breaking changes**\n\n`Table.new/0` has been supplemented with `Table.new/3` which takes `rows` and\nan optional `header` and `title`. This change was made as when the data is known\nupfront it was quite verbose doing:\n\n```elixir\nTable.new\n|> Table.add_rows(rows)\n|> Table.set_header(header)\n|> Table.set_title(title)\n|> Table.render\n```\n\nThe following can now be used instead:\n\n```\nTable.new(rows, header, title)\n|> Table.render\n```","ref":"changelog.html#v0-6-0-2016-01-07"},{"type":"extras","title":"v0.5.0 - Changelog","doc":"**No breaking changes**\n\n`TableRex.Table.set_column_meta` now supports applying the column\nmeta to a range of columns as so:\n\n```elixir\nTableRex.Table.set_column_meta(table, 0..3, align: :right)\n```\n\nThis would right-align columns 0 through 3.\n\nIt is different to using the `:all` atom as it allows for a subset.","ref":"changelog.html#v0-5-0"},{"type":"extras","title":"v0.4.0 - Changelog","doc":"**No breaking changes**\n\nAdded `TableRex.Table.set_header_meta/2` which allows a user\nto set the cell-level attributes (namely, alignment) of a\nheader cell. Header cells can now be aligned individually,\nseparately from the default which is picked up from the column.\n\nSee issue [#3](https://github.com/djm/table_rex/issues/3).","ref":"changelog.html#v0-4-0"},{"type":"extras","title":"v0.3.0 - Changelog","doc":"**No breaking changes**\n\nSimply an update to bump the version due to an oversight as the generated\ndocs for older version contained documentation for uncommitted files which\nwere not part of the package. This has been remedied as of this version.","ref":"changelog.html#v0-3-0"},{"type":"extras","title":"v0.2.0 - Changelog","doc":"**Breaking changes**\n\n* The original `TableRex.Table.render!/1`, `TableRex.Table.render!/2` and `TableRex.Table.render!/3` have been removed and consolidated with `TableRex.Table.render!/2`. Choosing a custom renderer module has been moved from a first class argument into the `:renderer` key of the options argument.\n\nWhat was previously:\n```elixir\nTable.new\n|> Table.add_row(row)\n|> Table.render(CustomRenderer.Module, horizontal_style: :off)\n```\n\nis now:\n\n```elixir\nTable.new\n|> Table.add_row(row)\n|> Table.render(renderer: CustomRenderer.Module, horizontal_style: :off)\n```\n\n** Other changes**\n\n* `TableRex.Table.render!/2` has been added as a brother to `TableRex.Table.render/2`. It raises `TableRex.Error` on failure and returns the rendered string directly as opposed to it's brother which returns an Erlang style `:ok/:error` tuple.","ref":"changelog.html#v0-2-0"},{"type":"extras","title":"v0.1.0 - Changelog","doc":"First release on hex.pm","ref":"changelog.html#v0-1-0"}],"content_type":"text/markdown"}